==> types_boto3_full-1.35.90.tar.gz: types_boto3_full-1.35.90/types_boto3_kinesis_video_media/type_defs.py <==
"""
Type annotations for kinesis-video-media service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_kinesis_video_media/type_defs/)

Usage::

    ```python
    from types_boto3_kinesis_video_media.type_defs import ResponseMetadataTypeDef

    data: ResponseMetadataTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from botocore.response import StreamingBody

from .literals import StartSelectorTypeType

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "GetMediaInputRequestTypeDef",
    "GetMediaOutputTypeDef",
    "ResponseMetadataTypeDef",
    "StartSelectorTypeDef",
    "TimestampTypeDef",
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class GetMediaOutputTypeDef(TypedDict):
    ContentType: str
    Payload: StreamingBody
    ResponseMetadata: ResponseMetadataTypeDef


class StartSelectorTypeDef(TypedDict):
    StartSelectorType: StartSelectorTypeType
    AfterFragmentNumber: NotRequired[str]
    StartTimestamp: NotRequired[TimestampTypeDef]
    ContinuationToken: NotRequired[str]


class GetMediaInputRequestTypeDef(TypedDict):
    StartSelector: StartSelectorTypeDef
    StreamName: NotRequired[str]
    StreamARN: NotRequired[str]

==> types_boto3_full-1.36.26.tar.gz: types_boto3_full-1.36.26/types_boto3_kinesis_video_media/type_defs.py <==
"""
Type annotations for kinesis-video-media service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_kinesis_video_media/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_kinesis_video_media.type_defs import ResponseMetadataTypeDef

    data: ResponseMetadataTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from botocore.response import StreamingBody

from .literals import StartSelectorTypeType

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
else:
    from typing import Dict
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "GetMediaInputTypeDef",
    "GetMediaOutputTypeDef",
    "ResponseMetadataTypeDef",
    "StartSelectorTypeDef",
    "TimestampTypeDef",
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class GetMediaOutputTypeDef(TypedDict):
    ContentType: str
    Payload: StreamingBody
    ResponseMetadata: ResponseMetadataTypeDef


class StartSelectorTypeDef(TypedDict):
    StartSelectorType: StartSelectorTypeType
    AfterFragmentNumber: NotRequired[str]
    StartTimestamp: NotRequired[TimestampTypeDef]
    ContinuationToken: NotRequired[str]


class GetMediaInputTypeDef(TypedDict):
    StartSelector: StartSelectorTypeDef
    StreamName: NotRequired[str]
    StreamARN: NotRequired[str]
